package Dist::Iller;

our $VERSION = '0.1101'; # VERSION

use strict;
use warnings;
use 5.10.1;

1;

# ABSTRACT: (deprecated)

__END__

=pod

=encoding UTF-8

=head1 NAME

Dist::Iller - (deprecated)

=head1 VERSION

version 0.1101

=head1 SYNOPSIS

  iller new Dist::Name

=head1 DESCRIPTION

Deprecated, and will be removed from CPAN shortly.

=head1 SEE ALSO

L<Dist::Zilla>

L<Dist::Milla>

L<Pod::Weaver>

L<Dist::Zilla::PluginBundle::Author::CSSON>

L<Pod::Weaver::PluginBundle::Author::CSSON>

=head1 AUTHOR

Erik Carlsson <info@code301.com>

=head1 COPYRIGHT AND LICENSE

This software is copyright (c) 2015 by Erik Carlsson.

This is free software; you can redistribute it and/or modify it under
the same terms as the Perl 5 programming language system itself.

=cut
